# Generated by Django 3.2 on 2023-02-23 14:56

from django.db import migrations


class Migration(migrations.Migration):

    dependencies = [
        ('log', '0008_alter_log_ip_type'),
    ]

    operations = [
        migrations.RenameField(
            model_name='log',
            old_name='ip_type',
            new_name='is_private',
        ),
    ]
