# Generated by Django 3.2 on 2023-02-23 02:03

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('log', '0003_auto_20230223_1048'),
    ]

    operations = [
        migrations.AddField(
            model_name='log',
            name='priv_address',
            field=models.CharField(blank=True, max_length=255, null=True),
        ),
    ]
