# Generated by Django 3.2 on 2023-02-23 14:55

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('log', '0007_log_ip_type'),
    ]

    operations = [
        migrations.AlterField(
            model_name='log',
            name='ip_type',
            field=models.BooleanField(blank=True, default=False, null=True),
        ),
    ]
