# Generated by Django 3.2 on 2023-02-23 00:29

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('log', '0001_initial'),
    ]

    operations = [
        migrations.AlterField(
            model_name='log',
            name='latitude',
            field=models.FloatField(blank=True, null=True),
        ),
        migrations.AlterField(
            model_name='log',
            name='longitude',
            field=models.FloatField(blank=True, null=True),
        ),
    ]
